@@ -68,16 +68,6 @@ class TelegramBot(MultiBot[TelegramClient]):
     # ----------------------------------------------------------- #
     # -------------------- PROTECTED METHODS -------------------- #
     # ----------------------------------------------------------- #
-    async def _accept_button_event(self, event: constants.TELEGRAM_EVENT | Message):
-        match event:
-            case Message():
-                event = event.original_event
-
-        try:
-            await event.answer()
-        except AttributeError:
-            pass
-
     # noinspection PyTypeChecker
     def _add_handlers(self):
         super()._add_handlers()
@@ -128,7 +118,7 @@ class TelegramBot(MultiBot[TelegramClient]):
         return User(
             platform=self.platform.value,
             id=original_user.id,
-            name=self._get_name_from_entity(original_user).strip(' @'),
+            name=self._get_name_from_entity(original_user),
             is_admin=is_admin,
             is_bot=original_user.bot,
             original_object=original_user
@@ -172,10 +162,14 @@ class TelegramBot(MultiBot[TelegramClient]):
 
         text = flanautils.remove_symbols(text, replace_with=' ')
         words = text.lower().split()
+
         for participant in await self.client.get_participants(chat.original_object):
-            user_name = self._get_name_from_entity(participant).strip(' @').lower()
+            user_name = self._get_name_from_entity(participant).lower()
             if user_name in words:
                 mentions.add(await self._create_user_from_telegram_user(participant, chat))
+        if chat.is_private:
+            if self.name.lower() in words:
+                mentions.add(await self.get_me())
 
         return list(mentions - None)
 
@@ -186,7 +180,7 @@ class TelegramBot(MultiBot[TelegramClient]):
     @return_if_first_empty('', exclude_self_types='TelegramBot', globals_=globals())
     def _get_name_from_entity(self, entity: telethon.hints.EntityLike) -> str:
         if isinstance(entity, telethon.types.User):
-            return f'@{entity.username}' if entity.username else entity.first_name
+            return entity.username or entity.first_name
         elif isinstance(entity, (telethon.types.Channel, telethon.types.Chat)):
             return entity.title
 
@@ -246,6 +240,16 @@ class TelegramBot(MultiBot[TelegramClient]):
     # -------------------------------------------------------- #
     # -------------------- PUBLIC METHODS -------------------- #
     # -------------------------------------------------------- #
+    async def accept_button_event(self, event: constants.TELEGRAM_EVENT | Message):
+        match event:
+            case Message():
+                event = event.original_event
+
+        try:
+            await event.answer()
+        except AttributeError:
+            pass
+
     # async def ban(self, user: int | str | User, chat: int | str | Chat | Message, seconds: int | datetime.timedelta = None):  # todo4 test en grupo de pruebas
     # if isinstance(user, User):
     #     user = user.original_object
